@@ -101,10 +101,10 @@ impl CipherSuite for CipherSuiteAes256CbcSha {
         if let Some(cg) = &self.cbc {
             cg.encrypt(pkt_rlh, raw)
         } else {
-            Err(Error::ErrOthers(
-                "CipherSuite has not been initialized, unable to encrypt".to_owned(),
+            Err(
+                Error::new("CipherSuite has not been initialized, unable to encrypt".to_owned())
+                    .into(),
             )
-            .into())
         }
     }
 
@@ -112,10 +112,10 @@ impl CipherSuite for CipherSuiteAes256CbcSha {
         if let Some(cg) = &self.cbc {
             cg.decrypt(input)
         } else {
-            Err(Error::ErrOthers(
-                "CipherSuite has not been initialized, unable to decrypt".to_owned(),
+            Err(
+                Error::new("CipherSuite has not been initialized, unable to decrypt".to_owned())
+                    .into(),
             )
-            .into())
         }
     }
 }
